package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;

public class DistributionPointName extends ASN1Encodable implements ASN1Choice {
   public static final int FULL_NAME = 0;
   public static final int NAME_RELATIVE_TO_CRL_ISSUER = 1;
   DEREncodable name;
   int type;

   public static DistributionPointName getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1TaggedObject.getInstance(obj, true));
   }

   public static DistributionPointName getInstance(Object obj) {
      if (obj != null && !(obj instanceof DistributionPointName)) {
         if (obj instanceof ASN1TaggedObject) {
            return new DistributionPointName((ASN1TaggedObject)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (DistributionPointName)obj;
      }
   }

   public DistributionPointName(int type, DEREncodable name) {
      this.type = type;
      this.name = name;
   }

   public DistributionPointName(int type, ASN1Encodable name) {
      this.type = type;
      this.name = name;
   }

   public DistributionPointName(ASN1TaggedObject obj) {
      if ((this.type = obj.getTagNo()) == 0) {
         this.name = GeneralNames.getInstance(obj, false);
      } else {
         this.name = ASN1Set.getInstance(obj, false);
      }

   }

   private void appendObject(StringBuffer buf, String sep, String name, String value) {
      buf.append("    ");
      buf.append(name);
      buf.append(":");
      buf.append(sep);
      buf.append("    ");
      buf.append("    ");
      buf.append(value);
      buf.append(sep);
   }

   public int getType() {
      return this.type;
   }

   public ASN1Encodable getName() {
      return (ASN1Encodable)this.name;
   }

   public DERObject toASN1Object() {
      DistributionPointName var10002 = this;
      int var2 = this.type;
      DEREncodable var1 = var10002.name;
      return new DERTaggedObject(false, var2, var1);
   }

   public String toString() {
      String var1 = System.getProperty("line.separator");
      StringBuffer var2;
      StringBuffer var10001 = var2 = new StringBuffer;
      var2.<init>();
      var2.append("DistributionPointName: [");
      var10001.append(var1);
      DistributionPointName var10000;
      String var3;
      if (this.type == 0) {
         var10000 = this;
         var3 = this.name.toString();
         var10000.appendObject(var2, var1, "fullName", var3);
      } else {
         var10000 = this;
         var3 = this.name.toString();
         var10000.appendObject(var2, var1, "nameRelativeToCRLIssuer", var3);
      }

      var2.append("]");
      var2.append(var1);
      return var2.toString();
   }
}
